package cz.moneta.test.regression.backoffice.callcenter.jenkinstests;

import cz.moneta.test.dsl.Harness;
import cz.moneta.test.dsl.util.credentials.Keys;
import cz.moneta.test.dsl.util.task.ufo.operations.OperationsTasks;
import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.harness.support.auth.Credentials;
import cz.moneta.test.harness.support.auth.Key;
import org.junit.jupiter.api.BeforeAll;

import static cz.moneta.test.harness.annotations.Environment.PPE;
import static cz.moneta.test.harness.annotations.Environment.TST1;

@TestScenario(name = "View transactions of client")
public class ViewTransactionsOfClient {
    private OperationsTasks operationsTasks;
    private String rcOfExistingClient;

    @BeforeAll
    public void getSetup(Harness harness) {
        operationsTasks = harness.tasks().ufo().operations();
        rcOfExistingClient = harness.getSystemOrConfigValue("cc.transactionClient.rc");
    }

    @TestCase(name = "View list of transactions and transaction detail of client", environments = {PPE, TST1})
    @JiraTestCase(id = "CC-T2127")
    public void viewTransactionsOfClient(Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {

        harness.withUfo()
                .openLoginPage()
                .then(operationsTasks.login().withCredentials(credentials))
                .fillSearchInput(rcOfExistingClient)
                .clickSearchClient()
                .onClientDetailsPage()
                .clickAccountList()
                .checkPlaceOfBusiness("PRAHA 4-BBC - 704")
                .clickTransactions()
                .clickFirstAccountStatementCheckbox()
                .clickViewTransactions()
                .clickDetailOfTransaction()
                .checkIdOfUser()
                .clickExitInWindowWithDetailOfTransaction()
                .clickBack()
                .clickClientDetailList();
    }
}
